@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.074-8-g42133a5
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.076';
+# git description: 0.076-1-gc984c68
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.077';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -195,7 +195,7 @@ sub meta_provider_plugins {
 
     my @plugins = (
         [ Authority => { authority => 'cpan:RSRCHBOY' } ],
-        qw{ MetaConfig MetaJSON },
+        qw{ MetaConfig MetaJSON MetaYAML },
         [ MetaNoIndex => { directory => [ qw{ corpus t } ] } ],
         'MetaProvides::Package',
 
@@ -360,7 +360,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.076 of Dist::Zilla::PluginBundle::RSRCHBOY - released March 05, 2018 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.077 of Dist::Zilla::PluginBundle::RSRCHBOY - released March 05, 2018 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
